Crea y configura perfiles de app
Los perfiles de aplicación de Bigtable (perfiles de app) te permiten especificar políticas de enrutamiento, opciones de procesamiento y parámetros de configuración de aislamiento de cargas de trabajo para las solicitudes de clientes entrantes. Puedes dirigir el tráfico a través de los nodos del clúster aprovisionados, ejecutar lecturas aisladas de alta capacidad de procesamiento con la computación sin servidores de Data Boost o enrutar lecturas puntuales a un nivel en memoria (vista previa) en instancias de Enterprise Plus.
Antes de comenzar
Antes de crear o configurar un perfil de la app, lee la siguiente documentación:
- Lee la Descripción general de los perfiles de app para obtener información sobre cómo funcionan los perfiles de app y la diferencia entre un perfil de app estándar para la computación estándar y un perfil de app de Data Boost para los trabajos de lectura sin servidores de alta capacidad de procesamiento. Si deseas obtener más información sobre las diferencias entre Data Boost y la computación con nodos de clúster aprovisionados, consulta la descripción general de Bigtable Data Boost.
- Si usas perfiles de aplicación estándar para configurar la replicación, lee la Descripción general de la replicación y los Ejemplos de configuraciones de replicación para decidir qué parámetros de configuración son los mejores para tu caso de uso.
- Si usas un perfil de aplicación de nivel en la memoria, consulta la Descripción general del nivel en la memoria.
Roles obligatorios
Para obtener los permisos que
necesitas para crear, configurar o borrar un perfil de app,
pídele a tu administrador que te otorgue el
rol de IAM administrador de Bigtable (roles/bigtable.admin) en la instancia.
Para obtener más información sobre cómo otorgar roles, consulta Administra el acceso a proyectos, carpetas y organizaciones.
También puedes obtener los permisos necesarios a través de roles personalizados o cualquier otro rol predefinido.
Crea un perfil de aplicación
Puedes crear muchos perfiles de app personalizados para cada instancia. Úsalos para controlar la manera en que las aplicaciones o las funciones de estas interactúan con una instancia. Por ejemplo, puedes usar un perfil de app en una aplicación por lote para separar su tráfico en un solo clúster, y otro para proporcionar una alta disponibilidad a otra aplicación.
Crea un perfil de aplicación estándar
Para crear un perfil de aplicación estándar, sigue estos pasos:
Console
En la consola de Google Cloud , abre la lista de instancias de Bigtable.
Haz clic en la instancia en la que deseas crear el perfil de la app.
En el panel izquierdo, haz clic en Perfiles de aplicación.
Haz clic en Crear perfil de aplicación.
Selecciona Estándar.
Haz clic en Siguiente.
Ingresa el ID de perfil de aplicación.
El ID de perfil de la aplicación es un identificador permanente para el perfil de la app. Tu aplicación proporciona este ID cuando se conecta a Bigtable.
Ingresa una descripción del perfil de la app.
En Enrutamiento del clúster, selecciona el enrutamiento de un solo clúster o de varios clústeres. Obtenga más información.
Si eliges Un solo clúster, sigue estos pasos:
En la lista Clúster, selecciona el clúster al que deseas enrutar las solicitudes.
Si necesitas habilitar las transacciones de una fila, selecciona la casilla de verificación Permitir transacciones de una fila.
Si eliges Varios clústeres:
- En la lista Grupo de clústeres, para enrutar solicitudes a cualquier clúster de la instancia, selecciona Cualquier clúster.
- Para limitar el enrutamiento de solicitudes solo a algunos clústeres de la instancia (enrutamiento de grupo de clústeres), selecciona cada clúster que quieras incluir en el grupo de enrutamiento y, luego, haz clic en Aceptar.
- Para enrutar las solicitudes de lectura y escritura de una sola fila a un clúster específico en función de la clave de fila de la solicitud, selecciona Habilitar afinidad de filas.
En Selecciona una prioridad de enrutamiento, asigna una prioridad de enrutamiento a tus solicitudes seleccionando una de las siguientes opciones:
- Alta: Se usa para solicitudes sensibles a la latencia.
- Medium: Se usa para solicitudes de uso general.
- Bajo: Se usa para tareas en segundo plano o para operaciones que no son tan urgentes.
Para crear el perfil de la app, haz clic en Crear.
Actualiza el código de tu aplicación para conectarte a Bigtable a fin de usar el nuevo perfil de la aplicación.
gcloud
Si no conoces el ID de la instancia, usa el comando
bigtable instances listpara ver una lista de las instancias de tu proyecto:gcloud bigtable instances listUsa el comando
bigtable app-profiles createpara crear un perfil de app:gcloud bigtable app-profiles create APP_PROFILE_ID \ --instance=INSTANCE_ID \ [--description=DESCRIPTION] \ [--force] \ [--route-any] \ [--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...] \ [--route-to=CLUSTER_ID] \ [--transactional-writes] \ [--priority=PRIORITY] \ [--row-affinity]Proporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.
El comando acepta las siguientes marcas opcionales:
--description=DESCRIPTION: Es una descripción detallada del perfil de la app.--force: Ignora las advertencias sobre posibles problemas y conflictos con otros perfiles de la app.--route-any: Habilita el enrutamiento de varios clústeres para enrutar solicitudes a cualquier clúster disponible.No puedes combinar esta marca con las marcas
--route-too--transactional-writes.--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...: Es una lista de clústeres a los que se deben enrutar las solicitudes. Usa esta opción si deseas enrutar solicitudes solo a algunos de los clústeres de la instancia.No puedes combinar esta marca con las marcas
--route-too--transactional-writes.--route-to=CLUSTER_ID: Es el ID del clúster al que se deben enrutar todas las solicitudes. Esta marca habilita el enrutamiento de un solo clúster.No puedes combinar esta marca con la marca
--route-any.--transactional-writes: Habilita las transacciones de una sola fila en el perfil de la app.No puedes combinar esta marca con las marcas
--route-anyo--restrict-to.--priority=PRIORITY: Es el nivel de prioridad que debe usar el perfil de la app. Los valores aceptados sonPRIORITY_HIGH,PRIORITY_MEDIUMoPRIORITY_LOW.--row-affinity: Habilita el enrutamiento con afinidad de filas en el perfil de la app.No puedes combinar esta marca con las marcas
--route-too--transactional-writes.
Actualiza el código de tu aplicación para conectarte a Bigtable a fin de usar el nuevo perfil de la aplicación.
Crea un perfil de aplicación de nivel en la memoria
Para crear un perfil de app en un clúster con el nivel en memoria habilitado, sigue estos pasos:
Console
En la consola de Google Cloud , abre la lista de instancias de Bigtable.
Haz clic en la instancia en la que deseas crear el perfil de la app.
En el panel izquierdo, haz clic en Perfiles de aplicación.
Haz clic en Crear perfil de aplicación.
Selecciona Nivel en la memoria.
Haz clic en Siguiente.
Ingresa el ID de perfil de aplicación.
El ID de perfil de la aplicación es un identificador permanente para el perfil de la app. Tu aplicación proporciona este ID cuando se conecta a Bigtable.
Ingresa una descripción del perfil de la app.
En Enrutamiento de clúster, selecciona un clúster con el nivel en la memoria habilitado.
Los clústeres de nivel en la memoria deben usar el enrutamiento de un solo clúster.
Si necesitas habilitar las transacciones de una fila, selecciona Permitir transacciones de una fila.
En Selecciona una prioridad de enrutamiento, asigna una prioridad de enrutamiento a tus solicitudes seleccionando una de las siguientes opciones:
- Alta: Se usa para solicitudes sensibles a la latencia.
- Medium: Se usa para solicitudes de uso general.
- Bajo: Se usa para tareas en segundo plano o para operaciones que no son tan urgentes.
Haz clic en Crear para crear el perfil de la app.
Actualiza el código de tu aplicación para conectarte a Bigtable a fin de usar el nuevo perfil de la aplicación.
gcloud
Si no conoces el ID de la instancia, usa el comando
bigtable instances listpara ver una lista de las instancias de tu proyecto:gcloud bigtable instances listUsa el comando
gcloud beta bigtable app-profiles createpara crear un perfil de app:gcloud beta bigtable app-profiles create APP_PROFILE_ID \ --instance=INSTANCE_ID \ --route-to=CLUSTER_ID \ --use-memory-layer \ [--description=DESCRIPTION] \ [--transactional-writes] \ [--priority=PRIORITY]Proporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.
El comando acepta las siguientes marcas opcionales:
--route-to=CLUSTER_ID: Es el ID del clúster al que se deben enrutar todas las solicitudes. Esta marca habilita el enrutamiento de un solo clúster.--use-memory-layer: Enruta las solicitudes con este perfil de aplicación al nivel en la memoria. Esta marca se limita a la edición Enterprise Plus y al enrutamiento de un solo clúster.--description=DESCRIPTION: Es una descripción detallada del perfil de la app.--transactional-writes: Habilita las transacciones de una sola fila en el perfil de la app.--priority=PRIORITY: Es el nivel de prioridad de las solicitudes enviadas con el perfil de la app. Los valores aceptados sonPRIORITY_HIGH,PRIORITY_MEDIUMoPRIORITY_LOW. Las prioridades de solicitud no afectan las solicitudes aptas para el nivel en la memoria.
Actualiza el código de tu aplicación para conectarte a Bigtable a fin de usar el nuevo perfil de la aplicación.
Crea un perfil de app de Data Boost
Para crear un perfil de aplicación de Data Boost, es decir, un perfil de aplicación que usa la computación sin servidores de Data Boost, sigue estos pasos. Para asegurarte de que tu carga de trabajo sea compatible con Data Boost, revisa las limitaciones.
Console
En la consola de Google Cloud , abre la lista de instancias de Bigtable.
Haz clic en la instancia en la que deseas crear el perfil de la app.
En el panel izquierdo, haz clic en Perfiles de aplicación.
Haz clic en Crear perfil de aplicación.
Selecciona Data Boost.
Haz clic en Siguiente.
Ingresa el ID de perfil de aplicación.
El ID de perfil de la aplicación es un identificador permanente para el perfil de la app. Tu aplicación proporciona este ID cuando se conecta a Bigtable.
Ingresa una descripción del perfil de la app.
En Enrutamiento del clúster, selecciona el clúster al que se enrutarán las solicitudes.
Haz clic en Crear perfil de la app para crear el perfil de la app.
Actualiza el código de tu aplicación para conectarte a Bigtable a fin de usar el nuevo perfil de la aplicación.
gcloud
Si no conoces el ID de la instancia, usa el comando
bigtable instances listpara ver una lista de las instancias de tu proyecto:gcloud bigtable instances listUsa el comando
gcloud beta bigtable app-profiles createpara crear un perfil de app:gcloud bigtable app-profiles create APP_PROFILE_ID \ --instance=INSTANCE_ID \ --data-boost \ --data-boost-compute-billing-owner=HOST_PAYS \ --route-to=CLUSTER_IDProporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.CLUSTER_ID: Es el ID del clúster al que se deben enrutar todas las solicitudes. Esta marca habilita el enrutamiento de un solo clúster.
Conéctate con un perfil de app personalizado
Después de crear un perfil de app personalizado, puedes actualizar tu código para que la aplicación use este perfil cuando se conecte a Bigtable.
En los siguientes ejemplos se muestra cómo especificar un perfil de la app cuando tu app crea un cliente de Bigtable y se conecta a una instancia. Reemplaza [APP_PROFILE_ID] con el valor apropiado.
C#
var client = BigtableClient.Create(appProfileId: "[APP_PROFILE_ID]");Comienza a usarlo
clientConf := bigtable.ClientConfig{AppProfile:"[APP_PROFILE_ID]"}
client, err = bigtable.NewClientWithConfig(ctx, project, instance, clientConf)Java de HBase
// If using BigtableOptions directly:
optionsBuilder.setAppProfileId("[APP_PROFILE_ID]");
// If using BigtableOptionsFactory:
configuration.set(BigtableOptionsFactory.APP_PROFILE_ID_KEY, "[APP_PROFILE_ID]");
// If using system properties, set "google.bigtable.app_profile.id" to
// "[APP_PROFILE_ID]"
// If using CloudBigtableIO for Cloud Dataflow:
config.withConfiguration(BigtableOptionsFactory.APP_PROFILE_ID_KEY,
"[APP_PROFILE_ID]");Node.js
const bigtable = new Bigtable({appProfileId: '[APP_PROFILE_ID]'});Python
from google.cloud import bigtable
client = bigtable.Client(project=project_id)
instance = client.instance(instance_id)
table = bigtable.table.Table(table_id, instance, '[APP_PROFILE_ID]')Actualiza un perfil de aplicación
Puedes ver los perfiles de app de una instancia y actualizar su configuración en cualquier momento. Bigtable te advierte sobre cualquier actualización que pueda causar cambios de comportamiento inesperados.
Para saber cómo actualizar un perfil de app de estándar a Data Boost o de Data Boost a estándar, consulta Cómo convertir un perfil de app.
Actualiza un perfil de aplicación estándar
Para actualizar un perfil de app estándar, sigue estos pasos:
Console
En la consola de Google Cloud , abre la lista de instancias de Bigtable.
Haz clic en la instancia con el perfil de la app que deseas actualizar.
En el panel izquierdo, haz clic en Perfiles de aplicación.
Haz clic en Editar perfil de aplicación para el perfil de aplicación que deseas actualizar.
Actualiza la configuración según sea necesario.
Haz clic en Guardar o, para salir sin guardar, haz clic en Cancelar.
gcloud
Si no conoces el ID de la instancia, usa el comando
bigtable instances listpara ver una lista de las instancias de tu proyecto:gcloud bigtable instances listSi no conoces el ID del perfil de app, usa el comando
bigtable app-profiles listpara ver una lista de los perfiles de app de la instancia:gcloud bigtable app-profiles list --instance=INSTANCE_IDReemplaza
INSTANCE_IDcon el identificador permanente de la instancia.Opcional: Usa el comando
bigtable app-profiles describepara ver la configuración del perfil de la app:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDProporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.
Usa el comando
bigtable app-profiles updatepara actualizar la configuración del perfil de la app:gcloud bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ [--description=DESCRIPTION] \ [--force] \ [--route-any] \ [--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...] [--route-to=CLUSTER_ID] \ [--transactional-writes] \ [--row-affinity]Proporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.
El comando acepta las siguientes marcas opcionales:
--description=DESCRIPTION: Es una descripción detallada del perfil de la app.--force: Ignora las advertencias sobre posibles problemas y conflictos con otros perfiles de la app.--route-any: Habilita el enrutamiento de varios clústeres para enrutar solicitudes a cualquier clúster disponible.No puedes combinar esta marca con las marcas
--route-too--transactional-writes.--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...: Es una lista de clústeres a los que se deben enrutar las solicitudes. Usa esta opción si deseas enrutar solicitudes solo a algunos de los clústeres de la instancia.No puedes combinar esta marca con las marcas
--route-too--transactional-writes.--route-to=CLUSTER_ID: Es el ID del clúster al que se deben enrutar todas las solicitudes. Esta marca habilita el enrutamiento de un solo clúster.No puedes combinar esta marca con la marca
--route-any.--transactional-writes: Habilita las transacciones de una sola fila en el perfil de la app.No puedes combinar esta marca con la marca
--route-any.--priority=PRIORITY: Es el nivel de prioridad que usa el perfil de la app. Los valores aceptados sonPRIORITY_HIGH,PRIORITY_MEDIUMoPRIORITY_LOW.
Actualiza un perfil de aplicación de nivel en la memoria
Para actualizar el perfil de una app en un clúster con el nivel en memoria habilitado, sigue estos pasos:
Console
En la consola de Google Cloud , abre la lista de instancias de Bigtable.
Haz clic en la instancia con el perfil de la app que deseas actualizar.
En el panel izquierdo, haz clic en Perfiles de aplicación.
Haz clic en Editar perfil de aplicación para el perfil de aplicación que deseas actualizar.
Actualiza la configuración según sea necesario.
Haz clic en Guardar o, para salir sin guardar, haz clic en Cancelar.
gcloud
Si no conoces el ID de la instancia, usa el comando
bigtable instances listpara ver una lista de las instancias de tu proyecto:gcloud bigtable instances listSi no conoces el ID del perfil de app, usa el comando
bigtable app-profiles listpara ver una lista de los perfiles de app de la instancia:gcloud bigtable app-profiles list --instance=INSTANCE_IDReemplaza
INSTANCE_IDcon el identificador permanente de la instancia.Opcional: Usa el comando
gcloud bigtable app-profiles describepara ver la configuración del perfil de la app:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDProporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.
Usa el comando
gcloud beta bigtable app-profiles updatepara actualizar la configuración del perfil de la app:gcloud beta bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --route-to=CLUSTER_ID \ [--description=DESCRIPTION] \ [--transactional-writes] \ [--priority=PRIORITY] \ [--use-memory-layer] \ [--no-use-memory-layer]Proporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.
El comando acepta las siguientes marcas opcionales:
--description=DESCRIPTION: Es una descripción detallada del perfil de la app.--route-to=CLUSTER_ID: Es el ID del clúster al que se deben enrutar todas las solicitudes. Esta marca habilita el enrutamiento de un solo clúster.--transactional-writes: Habilita las transacciones de una sola fila en el perfil de la app.--priority=PRIORITY: Es el nivel de prioridad que usa el perfil de la app. Los valores aceptados sonPRIORITY_HIGH,PRIORITY_MEDIUMoPRIORITY_LOW.--use-memory-layer: Enruta las solicitudes con este perfil de la app al nivel en memoria. Usa--no-use-memory-layerpara inhabilitar el enrutamiento de nivel en la memoria para este perfil de aplicación. Esta marca se limita a la edición Enterprise Plus y al enrutamiento de un solo clúster.
Actualiza un perfil de app de Data Boost
Para actualizar el clúster desde el que lee un perfil de app de Data Boost, sigue estos pasos:
Console
En la consola de Google Cloud , abre la lista de instancias de Bigtable.
En la columna Perfiles de la aplicación, haz clic en el perfil de la app que deseas ver o actualizar.
Si no ves el perfil de la app que quieres editar, puedes ver una lista completa haciendo clic en el nombre de la instancia y, luego, en Perfiles de aplicación en el panel izquierdo.
Selecciona el nuevo clúster al que se debe dirigir el tráfico y, luego, haz clic en Guardar.
gcloud
Si no conoces el ID de la instancia, usa el comando
bigtable instances listpara ver una lista de las instancias de tu proyecto:gcloud bigtable instances listSi no conoces el ID del perfil de app, usa el comando
bigtable app-profiles listpara ver una lista de los perfiles de app de la instancia:gcloud bigtable app-profiles list --instance=INSTANCE_IDReemplaza
INSTANCE_IDcon el identificador permanente de la instancia.Opcional: Usa el comando
gcloud bigtable app-profiles describepara ver la configuración del perfil de la app:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDProporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.
Usa el comando
gcloud beta bigtable app-profiles updatepara actualizar la configuración del perfil de la app:gcloud beta bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --route-to=CLUSTER_IDProporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.CLUSTER_ID: Es el ID del clúster nuevo desde el que se leerá.
Cómo convertir un perfil de aplicación
Puedes convertir un perfil de app estándar en un perfil de app de Data Boost o viceversa. Antes de convertir un perfil de la app, revisa la guía en Cambios en el perfil de la app.
Cómo cambiar de Standard a Data Boost
Antes de actualizar un perfil de app de estándar (nodos aprovisionados para el procesamiento) a la computación sin servidores de Data Boost, consulta las métricas de elegibilidad de Data Boost. También debes tener en cuenta las limitaciones de Data Boost.
Console
En la consola de Google Cloud , abre la lista de instancias de Bigtable.
En la columna Perfiles de aplicación, haz clic en el perfil de la app que deseas actualizar.
Si no ves el perfil de la app que deseas editar, puedes ver la lista completa si haces clic en el nombre de la instancia y, luego, en Perfiles de la aplicación en el panel izquierdo.
Selecciona Data Boost.
Selecciona el clúster al que se deben enrutar las solicitudes.
Haz clic en Guardar.
gcloud
Si no conoces el ID de la instancia, usa el comando
bigtable instances listpara ver una lista de las instancias de tu proyecto:gcloud bigtable instances listSi no conoces el ID del perfil de app, usa el comando
bigtable app-profiles listpara ver una lista de los perfiles de app de la instancia:gcloud bigtable app-profiles list --instance=INSTANCE_IDReemplaza
INSTANCE_IDcon el identificador permanente de la instancia.Opcional: Usa el comando
bigtable app-profiles describepara ver la configuración del perfil de la app:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDProporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.
Usa el comando
gcloud beta bigtable app-profiles updatepara convertir un perfil de app de estándar a Data Boost:gcloud bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --data-boost \ --data-boost-compute-billing-owner=HOST_PAYS \ --route-to=CLUSTER_IDProporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.CLUSTER_ID: Es el ID del clúster al que se deben enrutar todas las solicitudes. Esta marca habilita el enrutamiento de un solo clúster.
Cómo cambiar de Data Boost a estándar
Para cambiar un perfil de aplicación de Data Boost (computación sin servidores) a estándar (nodos aprovisionados para la computación), sigue estos pasos:
Console
En la consola de Google Cloud , abre la lista de instancias de Bigtable.
En la columna Perfiles de aplicación, haz clic en el perfil de la app que deseas actualizar.
Si no ves el perfil de la app que deseas editar, puedes ver la lista completa si haces clic en el nombre de la instancia y, luego, en Perfiles de la aplicación en el panel izquierdo.
Selecciona Estándar.
Haz clic en Siguiente.
Opcional: Edita la descripción del perfil de la app.
En Enrutamiento del clúster, selecciona el enrutamiento de un solo clúster o de varios clústeres. Obtenga más información.
Si eliges Un solo clúster, sigue estos pasos:
En la lista Clúster, selecciona el clúster al que deseas enrutar las solicitudes.
Si necesitas habilitar las transacciones de una fila, selecciona la casilla de verificación Permitir transacciones de una fila.
Si eliges Varios clústeres:
- En la lista Grupo de clústeres, para enrutar solicitudes a cualquier clúster de la instancia, selecciona Cualquier clúster.
- Para limitar el enrutamiento de solicitudes solo a algunos clústeres de la instancia (enrutamiento de grupo de clústeres), selecciona cada clúster que quieras incluir en el grupo de enrutamiento y, luego, haz clic en Aceptar.
- Para enrutar las solicitudes de lectura y escritura de una sola fila a un clúster específico en función de la clave de fila de la solicitud, selecciona Habilitar afinidad de filas.
En Selecciona una prioridad de enrutamiento, asigna una prioridad de enrutamiento a tus solicitudes seleccionando una de las siguientes opciones:
- Alta: Se usa para solicitudes sensibles a la latencia.
- Medium: Se usa para solicitudes de uso general.
- Baja: Se usa para tareas en segundo plano o para operaciones que no son tan urgentes.
Haz clic en Guardar.
gcloud
Si no conoces el ID de la instancia, usa el comando
bigtable instances listpara ver una lista de las instancias de tu proyecto:gcloud bigtable instances listSi no conoces el ID del perfil de app, usa el comando
bigtable app-profiles listpara ver una lista de los perfiles de app de la instancia:gcloud bigtable app-profiles list --instance=INSTANCE_IDReemplaza
INSTANCE_IDcon el identificador permanente de la instancia.Opcional: Usa el comando
bigtable app-profiles describepara ver la configuración del perfil de la app:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDUsa el comando
gcloud beta bigtable app-profiles updatepara convertir el perfil de la app:gcloud bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --standard \ [--route-any] \ [--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...] [--route-to=CLUSTER_ID] \ [--transactional-writes]
Proporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.
El comando acepta las siguientes marcas opcionales:
--route-any: Habilita el enrutamiento de varios clústeres para enrutar solicitudes a cualquier clúster disponible.No puedes combinar esta marca con las marcas
--route-too--transactional-writes.--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...: Es una lista de clústeres a los que se deben enrutar las solicitudes. Usa esta opción si deseas enrutar solicitudes solo a algunos de los clústeres de la instancia.No puedes combinar esta marca con las marcas
--route-too--transactional-writes.--route-to=CLUSTER_ID: Es el ID del clúster al que se deben enrutar todas las solicitudes. Esta marca habilita el enrutamiento de un solo clúster.No puedes combinar esta marca con la marca
--route-any.--transactional-writes: Habilita las transacciones de una sola fila en el perfil de la app.No puedes combinar esta marca con las marcas
--route-anyo--restrict-to.
Borra un perfil de actualización
Puedes borrar los perfiles de app personalizados de una instancia, pero no el perfil de la app predeterminado.
Sigue estos pasos para borrar un perfil de la app personalizado:
Console
En la consola de Google Cloud , abre la lista de instancias de Bigtable.
Haz clic en la instancia que contiene el perfil de la app que deseas borrar.
En el panel izquierdo, haz clic en Perfiles de aplicación.
Abre el menú Más acciones y haz clic en Borrar perfil de aplicación. Aparecerá un diálogo de confirmación.
Sigue las instrucciones del diálogo de confirmación y haz clic en Borrar.
gcloud
Si no conoces el ID de la instancia, usa el comando
bigtable instances listpara ver una lista de las instancias de tu proyecto:gcloud bigtable instances listSi no conoces el ID del perfil de app, usa el comando
bigtable app-profiles listpara ver una lista de los perfiles de app de la instancia:gcloud bigtable app-profiles list --instance=INSTANCE_IDReemplaza
INSTANCE_IDcon el identificador permanente de la instancia.Usa el comando
bigtable app-profiles deletepara borrar el perfil de la app:gcloud bigtable app-profiles delete APP_PROFILE_ID \ --instance=INSTANCE_ID \ [--force]Proporcione lo siguiente:
APP_PROFILE_ID: Es el identificador permanente del perfil de la app.INSTANCE_ID: Identificador permanente de la instancia.
El comando acepta la siguiente marca opcional:
--force: Ignora las advertencias sobre posibles problemas y conflictos con otros perfiles de la app.